<?php

/**
 * Class Full Calendar
 */
class WC_Full_Calendar_API
{
    /**
     * Init class
     */
    public function __construct()
    {
        add_action('admin_enqueue_scripts', [$this, 'register_assets']);
    }

    /**
     * Register assets for calendar
     *
     * @param string $hook
     * @return void
     */
    public function register_assets($hook)
    {
        $screen = get_current_screen();
        $screen_id = $screen ? $screen->id : '';

        if ($screen_id !== 'toplevel_page_rnb_admin') {
            return;
        }

        wp_register_script('moment', REDQ_ROOT_URL . '/assets/js/moment.js', ['jquery'], $ver = true, false);
        wp_enqueue_script('moment');

        wp_register_style('qtip2', '//cdnjs.cloudflare.com/ajax/libs/qtip2/3.0.3/jquery.qtip.min.css', [], $ver = false, $media = 'all');
        wp_enqueue_style('qtip2');

        wp_register_script('qtip2', '//cdn.jsdelivr.net/qtip2/3.0.3/jquery.qtip.min.js', ['jquery', 'moment'], $ver = true, true);
        wp_enqueue_script('qtip2');

        wp_register_style('fullcalendar', REDQ_ROOT_URL . '/assets/css/fullcalendar.css', [], $ver = false, $media = 'all');
        wp_enqueue_style('fullcalendar');

        wp_register_script('fullcalendar.min', REDQ_ROOT_URL . '/assets/js/fullcalendar.min.js', ['jquery'], $ver = false, true);
        wp_enqueue_script('fullcalendar.min');

        wp_register_script('locale-all', REDQ_ROOT_URL . '/assets/js/locale-all.js', ['jquery'], $ver = false, true);
        wp_enqueue_script('locale-all');

        wp_register_style('magnific-popup', REDQ_ROOT_URL . '/assets/css/magnific-popup.css', [], $ver = false, $media = 'all');
        wp_enqueue_style('magnific-popup');

        wp_register_script('magnific-popup', REDQ_ROOT_URL . '/assets/js/jquery.magnific-popup.min.js', ['jquery'], $ver = false, true);
        wp_enqueue_script('magnific-popup');

        $this->rnb_prepare_calendar_data($hook);
    }

    /**
     * Show all booking data on full calendar.
     *
     * @since 2.4.0
     *
     * @param mixed $hook
     */
    public function rnb_prepare_calendar_data($hook)
    {
        global $wpdb;
        $calendar_data = [];

        $calendarItems = $this->prepare_calendar_items();

        if (empty($calendarItems)) {
            return;
        }

        foreach ($calendarItems as $key => $item) {

            if (array_key_exists('start', $item) && array_key_exists('end', $item)) {
                $calendar_data[$key] = $item;
            }

            if (array_key_exists('start', $item) && !array_key_exists('end', $item)) {
                $start_info = isset($item['start_time']) && !empty($item['start_time']) ? $item['start'] . 'T' . $item['start_time'] : $item['start'];
                $return_info = isset($item['return_time']) && !empty($item['return_time']) ? $item['start'] . 'T' . $item['return_time'] : $item['start'];

                $item['start'] = rnb_format_date_time($start_info);
                $item['end'] = rnb_format_date_time($return_info);

                $calendar_data[$key] = $item;
            }

            if (array_key_exists('end', $item) && !array_key_exists('start', $item)) {
                $start_info = isset($item['start_time']) && !empty($item['start_time']) ? $item['end'] . 'T' . $item['start_time'] : $item['end'];
                $return_info = isset($item['return_time']) && !empty($item['return_time']) ? $item['end'] . 'T' . $item['return_time'] : $item['end'];

                $item['start'] = rnb_format_date_time($start_info);
                $item['end'] = rnb_format_date_time($return_info);

                $calendar_data[$key] = $item;
            }

            if (array_key_exists('start', $item) && array_key_exists('end', $item)) {
                $start_info = isset($item['start_time']) && !empty($item['start_time']) ? $item['start'] . 'T' . $item['start_time'] : $item['start'];
                $return_info = isset($item['return_time']) && !empty($item['return_time']) ? $item['end'] . 'T' . $item['return_time'] : $item['end'];

                $item['start'] = rnb_format_date_time($start_info);
                $item['end'] = rnb_format_date_time($return_info);

                $calendar_data[$key] = $item;
            }
        }

        wp_register_script('redq-admin-page', REDQ_ROOT_URL . '/assets/js/admin-page.js', ['jquery'], $ver = false, true);
        wp_enqueue_script('redq-admin-page');

        $loc_data = [
            'calendar_data'     => $calendar_data,
            'lang_domain'       => get_option('rnb_lang_domain', 'en'),
            'day_of_week_start' => get_option('rnb_day_of_week_start', 1) - 1,
        ];

        wp_localize_script('redq-admin-page', 'REDQRENTALFULLCALENDER', $loc_data);
    }

    /**
     * Prepare calendar items
     *
     * @return array
     */
    public function prepare_calendar_items()
    {
        $results = [];

        $args = [
            'post_type'      => 'shop_order',
            'post_status'    => 'any',
            'posts_per_page' => -1,
        ];

        $posts = get_posts($args);

        if (empty($posts)) {
            return $results;
        }

        foreach ($posts as $post) {

            if ($post->post_status === 'wc-rnb-fake-order') {
                continue;
            }

            $order_id = $post->ID;
            $order    = new WC_Order($order_id);

            if (!count($order->get_items())) {
                continue;
            }

            foreach ($order->get_items() as $item) {

                $item_data = $item->get_data();

                $item_id    = $item_data['id'];
                $product_id = $item_data['product_id'];
                $quantity   = $item_data['quantity'];

                $results[$item_id]['post_status'] = $post->post_status;
                $results[$item_id]['title'] = get_the_title($product_id) . ' ×' . $quantity;
                $results[$item_id]['link'] = get_the_permalink($product_id);
                $results[$item_id]['id'] = $order_id;
                $results[$item_id]['description'] = '<table cellspacing="0" class="redq-rental-display-meta"><tbody><tr><th>' . __('Order ID:', 'redq-rental') . '</th><td>#' . $order_id . '</td></tr>';
                $results[$item_id]['description'] .= '<table cellspacing="0" class="redq-rental-display-meta"><tbody><tr><th>' . __('Quantity:', 'redq-rental') . '</th><td>' . $quantity . '</td></tr>';

                $is_translated = apply_filters('wpml_element_has_translations', null, $product_id, 'product');
                $item_details = $item->get_formatted_meta_data('');

                foreach ($item_details as $order_item_key => $item_detail) {
                    if ('_pickup_hidden_datetime' !== $item_detail->key && '_return_hidden_datetime' !== $item_detail->key && '_return_hidden_days' !== $item_detail->key && 'booking_inventory' !== $item_detail->key) {
                        $results[$item_id]['description'] .= '<tr><th>' . $item_detail->key . '</th><td>' . $item_detail->value . '</td></tr>';
                    }

                    if ('_pickup_hidden_datetime' === $item_detail->key) {
                        $pickup_datetime = explode('|', $item_detail->value);
                        $results[$item_id]['start'] = $pickup_datetime[0];
                        $results[$item_id]['start_time'] = isset($pickup_datetime[1]) ? $pickup_datetime[1] : '';
                    }

                    if ('_return_hidden_datetime' === $item_detail->key) {
                        $return_datetime = explode('|', $item_detail->value);
                        $results[$item_id]['end'] = $return_datetime[0];
                        $results[$item_id]['return_date'] = $return_datetime[0];
                        $results[$item_id]['return_time'] = isset($return_datetime[1]) ? $return_datetime[1] : '';
                    }

                    $results[$item_id]['url'] = admin_url('post.php?post=' . absint($order->get_id()) . '&action=edit');
                }

                //Only for backend orders
                $backend_item_details = wc_get_order_item_meta($item_id, 'rnb_hidden_order_meta');
                if ($backend_item_details) {
                    $results[$item_id]['start'] = $backend_item_details['pickup_date'];
                    $results[$item_id]['start_time'] = $backend_item_details['pickup_time'];

                    $results[$item_id]['end'] = $backend_item_details['return_date'];
                    $results[$item_id]['return_time'] = $backend_item_details['return_time'];
                }
                //End

                $order_total = $order->get_formatted_order_total();

                $results[$item_id]['description'] .= '<tr><th>' . esc_html__('Order Total', 'redq-rental') . '</th><td>' . $order_total . '</td>';
                $results[$item_id]['description'] .= '</tbody></table>';
            }
        }

        return $results;
    }
}

new WC_Full_Calendar_API();
